/**
 * apeman bud for mock files.
 * @memberof module:apeman-bud-mock/lib
 * @function setup
 * @param {string} name - Name of mock page.
 * @param {object} params - Template params.
 * @returns {object} - Coz bud configuration.
 */

"use strict";

const argx = require('argx'),
    pkg = require('../package.json'),
    assert = require('assert'),
    stringcase = require('stringcase'),
    fs = require('fs');

/** @lends setup */
function setup(name, params) {
    let args = argx(arguments);
    name = args.shift('string');
    assert.ok(name, "name is required.");
    params = args.shift('object') || {};

    function _bud(tmpl, filename) {
        return {
            force: false,
            mode: '644',
            mkdirp: true,
            path: `${stringcase.snakecase(name)}/${filename}`,
            tmpl: fs.readFileSync(`${__dirname}/../asset/${tmpl}`).toString(),
            data: {
                name: name,
                params: params,
                generator: 'coz',
                today: new Date().toLocaleDateString(),
                pkg: pkg
            }
        }
    }

    let snakeName = stringcase.snakecase(name);
    return [
        _bud('browser.jsx.hbs', `${snakeName}.browser.jsx`),
        _bud('component.jsx.hbs', `${snakeName}.component.jsx`),
        _bud('html.jsx.hbs', `${snakeName}.html.jsx`)
    ]


}

module.exports = setup;
